@@ -5,7 +5,7 @@
     author               : 2003 Massimo Callegari
     email                : massimocallegari@yahoo.it
  ***************************************************************************/
- 
+
 /***************************************************************************
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -14,7 +14,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
- 
+
 #ifndef _PLUGIN_KATE_SYMBOLVIEWER_H_
 #define _PLUGIN_KATE_SYMBOLVIEWER_H_
 
@@ -38,6 +38,7 @@
 #include <klocale.h>
 #include <klistview.h>
 #include <kiconloader.h>
+#include <kconfig.h>
 
 class KatePluginSymbolViewerView : public QObject, public KXMLGUIClient
 {
@@ -46,7 +47,7 @@ class KatePluginSymbolViewerView : public QObject, public KXMLGUIClient
   public:
     KatePluginSymbolViewerView (Kate::MainWindow *w);
     virtual ~KatePluginSymbolViewerView ();
-    
+
     void parseSymbols(void);
 
   public slots:
@@ -64,6 +65,7 @@ class KatePluginSymbolViewerView : public QObject, public KXMLGUIClient
   private:
     QPopupMenu *popup;
     KListView *symbols;
+    QWidget *dock;
     bool m_Active;
     int m_macro, m_struct, m_func;
     bool macro_on, struct_on, func_on;
@@ -119,30 +121,29 @@ class KatePluginSymbolViewer : public Kate::Plugin, Kate::PluginViewInterface, K
   public:
     KatePluginSymbolViewer( QObject* parent = 0, const char* name = 0, const QStringList& = QStringList() );
     virtual ~KatePluginSymbolViewer();
-    
+
     void addView (Kate::MainWindow *win);
     void removeView (Kate::MainWindow *win);
 
     uint configPages () const { return 1; }
     Kate::PluginConfigPage *configPage (uint , QWidget *w, const char *name=0);
-    QString configPageName(uint) const { return i18n("Symbol Viewer Options"); };
+    QString configPageName(uint) const { return i18n("Symbol Viewer"); };
     QString configPageFullName(uint) const { return i18n("Symbol Viewer Configuration Page"); };
     QPixmap configPagePixmap (uint number = 0, int size = KIcon::SizeSmall) const { return 0L; };
-  
+
   public slots:
     void applyConfig( KatePluginSymbolViewerConfigPage* );
 
   private:
-    void initConfigPage( KatePluginSymbolViewerConfigPage* );    
-  
+    void initConfigPage( KatePluginSymbolViewerConfigPage* );
+
   private:
-    QPtrList<KatePluginSymbolViewerView> m_views; 
-    KatePluginSymbolViewerView *m_SymbolView;
-    KConfig* pConfig;
+    QPtrList<KatePluginSymbolViewerView> m_views;
+    KConfig pConfig;
 };
 
 /* XPM */
-static const char* const class_xpm[] = { 
+static const char* const class_xpm[] = {
 "16 16 10 1",
 " 	c None",
 ".	c #000000",
