@@ -9,29 +9,12 @@
 #include <kate/view.h>
 #include <kate/viewmanager.h>
 
-#include <klibloader.h>
-#include <klocale.h>
-
-class KatePluginFactory : public KLibFactory
-{
-  Q_OBJECT
-
-  public:
-    KatePluginFactory();
-    virtual ~KatePluginFactory();
-
-    virtual QObject* createObject( QObject* parent = 0, const char* pname = 0, const char* name = "QObject", const QStringList &args = QStringList() );
-
-  private:
-    static KInstance* s_instance;
-};
-
 class KatePluginHelloWorld : public Kate::Plugin, Kate::PluginViewInterface
 {
   Q_OBJECT
 
   public:
-    KatePluginHelloWorld( QObject* parent = 0, const char* name = 0 );
+    KatePluginHelloWorld( QObject* parent = 0, const char* name = 0, const QStringList& = QStringList() );
     virtual ~KatePluginHelloWorld();
 
     void addView (Kate::MainWindow *win);
