@@ -81,6 +81,9 @@ void ModelinePlugin::removeView(Kate::MainWindow *win)
 
 void ModelinePlugin::applyModeline()
 {
+        if (!application()->activeMainWindow())
+          return;
+
 	Kate::Document* doc = application()->documentManager()->activeDocument();
 	Kate::View* view = application()->activeMainWindow()->viewManager()->activeView();
 	if( !doc || !view ) return;
