@@ -15,12 +15,11 @@
 /**
 @author Stephan Mres
 */
-class CWidgetSnippets : public CWidgetSnippetsBase
-{
+class CWidgetSnippets : public CWidgetSnippetsBase {
 public:
-    CWidgetSnippets( QWidget* parent = 0, const char* name = 0, WFlags fl = 0 );
+  CWidgetSnippets( QWidget* parent = 0, const char* name = 0, WFlags fl = 0 );
 
-    ~CWidgetSnippets();
+  ~CWidgetSnippets();
 
 };
 
