@@ -15,36 +15,34 @@
  *                                                                         *
  ***************************************************************************/
 
-/* $Id: domlistviewitem.cpp,v 1.5 2002/09/26 07:46:08 faure Exp $ */
- 
-#include <qpainter.h>
-
 #include "domlistviewitem.h"
+
+#include <qpainter.h>
 #include <qlistview.h>
 #include <qapplication.h>
 
 #include <kglobalsettings.h>
 
-DOMListViewItem::DOMListViewItem( QListView *parent )
-  : QListViewItem( parent )
+DOMListViewItem::DOMListViewItem( const DOM::Node &node, QListView *parent )
+  : QListViewItem( parent ), m_node(node)
 {
   init();
 }
 
-DOMListViewItem::DOMListViewItem( QListView *parent, QListViewItem *after)
-  : QListViewItem( parent, after )
+DOMListViewItem::DOMListViewItem( const DOM::Node &node, QListView *parent, QListViewItem *after)
+  : QListViewItem( parent, after ), m_node(node)
 {
   init();
 }
 
-DOMListViewItem::DOMListViewItem( QListViewItem *parent )
-  : QListViewItem( parent )
+DOMListViewItem::DOMListViewItem( const DOM::Node &node, QListViewItem *parent )
+  : QListViewItem( parent ), m_node(node)
 {
   init();
 }
 
-DOMListViewItem::DOMListViewItem( QListViewItem *parent, QListViewItem *after)
-  : QListViewItem( parent, after )
+DOMListViewItem::DOMListViewItem( const DOM::Node &node, QListViewItem *parent, QListViewItem *after)
+  : QListViewItem( parent, after ), m_node(node)
 {
   init();
 }
@@ -58,6 +56,7 @@ void DOMListViewItem::init()
 {
   m_color = QApplication::palette().color( QPalette::Active, QColorGroup::Text );
   m_font = KGlobalSettings::generalFont();
+  clos = false;
 }
 
 void DOMListViewItem::paintCell( QPainter *p, const QColorGroup &cg, int column, int width, int alignment )
