@@ -216,26 +216,26 @@ void DefaultPlugin::loadInformation(DOM::HTMLElement node)
     KFileItem *that = const_cast<KFileItem *>(item);
     
     DOM::DOMString innerHTML;
-    innerHTML += "<ul class=\"info\"><nobr><b>" + i18n("Type") + ": </b>";
+    innerHTML += "<ul class=\"info\"><b>" + i18n("Type") + ": </b>";
     innerHTML += that->determineMimeType()->comment();
-    innerHTML += "</nobr></ul><ul class=\"info\"><nobr><b>" + i18n("Size") + ": </b>";
+    innerHTML += "</ul><ul class=\"info\"><b>" + i18n("Size") + ": </b>";
     innerHTML += KIO::convertSize(item->size());
-    innerHTML += "</nobr></ul><ul class=\"info\"><nobr><b>" + i18n("User") + ": </b>";
+    innerHTML += "</ul><ul class=\"info\"><b>" + i18n("User") + ": </b>";
     innerHTML += item->user();
-    innerHTML += "</nobr></ul><ul class=\"info\"><nobr><b>" + i18n("Group") + ": </b>";
+    innerHTML += "</ul><ul class=\"info\"><b>" + i18n("Group") + ": </b>";
     innerHTML += item->group();
-    innerHTML += "</nobr></ul><ul class=\"info\"><nobr><b>" + i18n("Permissions") + ": </b>";
+    innerHTML += "</ul><ul class=\"info\"><b>" + i18n("Permissions") + ": </b>";
     innerHTML += (item->permissionsString());
-    innerHTML += "</nobr></ul><ul class=\"info\"><nobr><b>" + i18n("Modified") + ": </b>";
+    innerHTML += "</ul><ul class=\"info\"><b>" + i18n("Modified") + ": </b>";
     innerHTML += item->timeString(KIO::UDS_MODIFICATION_TIME);
-    innerHTML += "</nobr></ul><ul class=\"info\"><nobr><b>" + i18n("Accessed") + ": </b>";
+    innerHTML += "</ul><ul class=\"info\"><b>" + i18n("Accessed") + ": </b>";
     innerHTML += item->timeString(KIO::UDS_ACCESS_TIME);
-    innerHTML += "</nobr></ul>";
+    innerHTML += "</ul>";
         
     if(item->isLink()){
-      innerHTML += "<ul class=\"info\"><nobr><b>" + i18n("Linktarget") + ": </b>";
+      innerHTML += "<ul class=\"info\"><b>" + i18n("Linktarget") + ": </b>";
       innerHTML += item->linkDest();
-      innerHTML += "</nobr></ul>";
+      innerHTML += "</ul>";
     }
         
     if(!item->isDir()){
@@ -251,7 +251,7 @@ void DefaultPlugin::loadInformation(DOM::HTMLElement node)
           if(group.isValid()){
             nam.setNum(id);
             
-            innerHTML += "<ul class=\"info\"><nobr><a class=\"infotitle\" id=\"info_" + nam + "\" href=\"more://info_" + nam + "\">" + group.translatedName() + "</a></nobr></ul>";
+            innerHTML += "<ul class=\"info\"><a class=\"infotitle\" id=\"info_" + nam + "\" href=\"more://info_" + nam + "\">" + group.translatedName() + "</a></ul>";
             
             QStringList keys = group.supportedKeys();
           
@@ -260,9 +260,9 @@ void DefaultPlugin::loadInformation(DOM::HTMLElement node)
               
               if(metaInfoItem.isValid()){
               
-                innerHTML += "<ul class=\"info\" style=\"display:none\"><nobr><b name=\"info_" + nam + "\">" + metaInfoItem.translatedKey() + ": </b>";
+                innerHTML += "<ul class=\"info\" style=\"display:none\"><b name=\"info_" + nam + "\">" + metaInfoItem.translatedKey() + ": </b>";
                 innerHTML += metaInfoItem.string();
-                innerHTML += "</nobr></ul>";
+                innerHTML += "</ul>";
               }
             }
             
@@ -291,15 +291,15 @@ void DefaultPlugin::loadInformation(DOM::HTMLElement node)
     }
  
     DOM::DOMString innerHTML;
-    innerHTML += "<ul class=\"info\"><nobr><b>" + i18n("Size") + ": </b>";
+    innerHTML += "<ul class=\"info\"><b>" + i18n("Size") + ": </b>";
     innerHTML += KIO::convertSize(size);
-    innerHTML += "</nobr></ul><ul class=\"info\"><nobr><b>" + i18n("Files") + ": </b>";
+    innerHTML += "</ul><ul class=\"info\"><b>" + i18n("Files") + ": </b>";
     innerHTML += QString().setNum(files);
-    innerHTML += "</nobr></ul><ul class=\"info\"><nobr><b>" + i18n("Folders") + ": </b>";
+    innerHTML += "</ul><ul class=\"info\"><b>" + i18n("Folders") + ": </b>";
     innerHTML += QString().setNum(dirs);
-        innerHTML += "</ul><ul class=\"info\"><nobr><b>" + i18n("Total Entries") + ": </b>";
+        innerHTML += "</ul><ul class=\"info\"><b>" + i18n("Total Entries") + ": </b>";
     innerHTML += QString().setNum(m_items.count());
-    innerHTML += "</nobr></ul>";    
+    innerHTML += "</ul>";    
     node.setInnerHTML(innerHTML);
   }
   m_functions->show("info");
